from sdsRayanArvin.Dataset import AlertRuleData
from sdsRayanArvin.Repository import Repository


class AlertRule(Repository):
    def allAlertRule(self):
        res = self.Request.sendWithToken('GET', 'all_alert_communication')
        try:
            return AlertRuleData(res['Alert_Com']).alert_com
        except:
            return []



from enum import Enum
from datetime import datetime
from typing import List


class TypeEnum(Enum):
    CALL = "call"
    SMS = "sms"


class AlertCOM:
    ID_alert_communication: int
    phone: str
    ID_org: int
    ID_rule: int
    type: TypeEnum
    created_at: datetime
    updated_at: datetime

    def __init__(self, ID_alert_communication: int, phone: str, ID_org: int, ID_rule: int, type: TypeEnum, created_at: datetime, updated_at: datetime) -> None:
        self.ID_alert_communication = ID_alert_communication
        self.phone = phone
        self.ID_org = ID_org
        self.ID_rule = ID_rule
        self.type = type
        self.created_at = created_at
        self.updated_at = updated_at


class AlertRuleData:
    data: List[AlertCOM] = []

    def __init__(self, data) -> None:
        self.data = []
        for param in data:
            self.data.append(AlertCOM(**dict(param)))



from .UserData import UserData
from .ObjectData import ObjectData
from .DeviceData import DeviceData
from .WorkflowsData import WorkflowsData
from .RuleData import RuleData
from .AuxStationData import AuxStationData
from .WeatherData import WeatherData
from .AlertRuleData import AlertRuleData
